Crate binsec

Crate binsec 

Implements the main interface necessary in order to parse binary inputs. Should be used to detect format and security mitigations for a single binary.

Modules

check
sarif
Native SARIF 2.1.0 generation, strict validation, and Markdown rendering.

Structs

Detector
Interfaces static analysis and wraps around parsed information for serialization.

Enums

BinError
Custom error type for all errors types that binsec might encounter
Format
Output format selected on the command line.

Type Aliases

BinResult